@@ -168,7 +168,7 @@ class Postgres_Handler:
                 values = sql.SQL(', ').join(
                     map(sql.Placeholder, kwargs.keys())
                 ),
-                table_name = kwargs[self.table_name_key]
+                table_name =sql.Identifier(kwargs[self.table_name_key])
             )
         )
     
